#
# Conditional build:
%bcond_without  kernel		# don't build kernel modules
%bcond_without	userspace	# don't build userspace packages
%bcond_with	verbose		# verbose kernel module build
#
# The goal here is to have main, userspace, package built once with
# simple release number, and only rebuild kernel packages with kernel
# version as part of release number, without the need to bump release
# with every kernel change.
%if 0%{?_pld_builder:1} && %{with kernel} && %{with userspace}
%{error:kernel and userspace cannot be built at the same time on PLD builders}
exit 1
%endif

%if %{without userspace}
# nothing to be placed to debuginfo package
%define		_enable_debug_packages	0
%endif

%define		_duplicate_files_terminate_build	0

%define	pname	tpm_emulator
%define	rel	15
Summary:	Software-based TPM and MTM Emulator
Summary(pl.UTF-8):	Programowy emulator TPM i MTM
Name:		%{pname}%{?_pld_builder:%{?with_kernel:-kernel}}%{_alt_kernel}
Version:	0.7.4
Release:	%{rel}%{?_pld_builder:%{?with_kernel:@%{_kernel_ver_str}}}
License:	GPL v2+
Group:		Applications/System
Source0:	http://downloads.sourceforge.net/tpm-emulator.berlios/%{pname}-%{version}.tar.gz
# Source0-md5:	e26becb8a6a2b6695f6b3e8097593db8
Patch0:		%{pname}-libdir.patch
Patch1:		linux-3.19.patch
Patch2:		linux-4.1.patch
Patch3:		linux-4.7.patch
URL:		http://tpm-emulator.berlios.de/
BuildRequires:	cmake >= 2.4
BuildRequires:	gmp-devel
BuildRequires:	rpmbuild(macros) >= 1.701
%{?with_kernel:%{expand:%buildrequires_kernel kernel%%{_alt_kernel}-module-build >= 3:2.6.20.2}}
Requires:	%{name}-libs = %{version}-%{rel}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Software-based TPM and MTM Emulator.

%description -l pl.UTF-8
Programowy emulator TPM i MTM.

%package libs
Summary:	TSS-conformant device driver library for the emulator
Summary(pl.UTF-8):	Biblioteka sterownika urządzenia zgodnego z TSS dla emulatora
Group:		Libraries

%description libs
TSS-conformant device driver library for the emulator.

%description libs -l pl.UTF-8
Biblioteka sterownika urządzenia zgodnego z TSS dla emulatora.

%package devel
Summary:	Header file for TDDL library
Summary(pl.UTF-8):	Plik nagłówkowy biblioteki TDDL
Group:		Development/Libraries
Requires:	%{name}-libs = %{version}-%{rel}

%description devel
Header file for TDDL library.

%description devel -l pl.UTF-8
Plik nagłówkowy biblioteki TDDL.

%package static
Summary:	Static TDDL library
Summary(pl.UTF-8):	Statyczna biblioteka TDDL
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{rel}

%description static
Static TDDL library.

%description static -l pl.UTF-8
Statyczna biblioteka TDDL.

%define	kernel_pkg()\
%package -n kernel%{_alt_kernel}-char-tpmd\
Summary:	Kernel module that provides /dev/tpm device\
Summary(pl.UTF-8):	Moduł jądra udostępniający urządzenie /dev/tpm\
Release:	%{rel}@%{_kernel_ver_str}\
Group:		Base/Kernel\
%requires_releq_kernel\
Requires(postun):	%releq_kernel\
\
%description -n kernel%{_alt_kernel}-char-tpmd\
Kernel module that provides /dev/tpm device for backward compatibility\
and forwards the received commands to tpmd.\
\
%description -n kernel%{_alt_kernel}-char-tpmd -l pl.UTF-8\
Moduł jądra udostępniający dla kompatybilności urządzenie /dev/tpm i\
przekazujący odebrane polecenia do tpmd.\
\
%if %{with kernel}\
%files -n kernel%{_alt_kernel}-char-tpmd\
%defattr(644,root,root,755)\
/lib/modules/%{_kernel_ver}/misc/tpmd_dev.ko*\
/lib/udev/rules.d/80-tpmd_dev.rules\
%endif\
\
%post	-n kernel%{_alt_kernel}-char-tpmd\
%depmod %{_kernel_ver}\
\
%postun	-n kernel%{_alt_kernel}-char-tpmd\
%depmod %{_kernel_ver}\
%{nil}

%define build_kernel_pkg()\
%build_kernel_modules -m tpmd_dev -C tpmd_dev/linux\
%install_kernel_modules -D installed -m tpmd_dev/linux/tpmd_dev -d misc\
%{nil}

%{?with_kernel:%{expand:%create_kernel_packages}}

%prep
%setup -q -n %{pname}-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

# separate kernel module from userspace build
echo > tpmd_dev/CMakeLists.txt

%build
mkdir build
cd build
%cmake ..
%if %{with userspace}
%{__make}
%endif
cd ..
%if %{with kernel}
ln -sf ../../build/config.h tpmd_dev/linux/config.h
%{__make} -C tpmd_dev/linux tpmd_dev.rules
%{expand:%build_kernel_packages}
%endif

%install
rm -rf $RPM_BUILD_ROOT

%if %{with userspace}
%{__make} -C build install \
	DESTDIR=$RPM_BUILD_ROOT
%endif

%if %{with kernel}
install -d $RPM_BUILD_ROOT/lib/udev/rules.d
cp -p tpmd_dev/linux/tpmd_dev.rules $RPM_BUILD_ROOT/lib/udev/rules.d/80-tpmd_dev.rules
cp -a installed/* $RPM_BUILD_ROOT
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post	libs -p /sbin/ldconfig
%postun	libs -p /sbin/ldconfig

%if %{with userspace}
%files
%defattr(644,root,root,755)
%doc AUTHORS ChangeLog README
%attr(755,root,root) %{_bindir}/tpmd

%files libs
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libtddl.so.*.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libtddl.so.1.2

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libtddl.so
%{_includedir}/tddl.h

%files static
%defattr(644,root,root,755)
%{_libdir}/libtddl.a
%endif
%changelog
* Fri Jan 27 2017 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/tpm_emulator.git;a=log;h=auto/th/tpm_emulator-0.7.4-15

* Mon Aug 01 2016 Jan Rękorajski <baggins@pld-linux.org> 6e1dd8e
- fix building with linux 4.7
- rel 15

* Sat Jul 04 2015 Jan Rękorajski <baggins@pld-linux.org> 3ead4e6
- fixed building with linux 4.1
- rel 14

* Mon Mar 30 2015 Jan Rękorajski <baggins@pld-linux.org> 8fe378a
- fix building with linux 3.19
- rel 13

* Sun Mar 01 2015 Jan Rękorajski <baggins@pld-linux.org> a546689
- x32 rebuild
- release 12 (by relup.sh)

* Tue Jan 27 2015 Jan Rękorajski <baggins@pld-linux.org> 9799b8e
- rel 11

* Tue Jan 27 2015 Jan Rękorajski <baggins@pld-linux.org> 0b135cc
- updated kernel modules build system

* Tue Jan 27 2015 Jan Rękorajski <baggins@pld-linux.org> 0f8a9f1
- drop non-dist kernel support

* Mon Oct 28 2013 Jan Rękorajski <baggins@pld-linux.org> 89bab1a
- add -kernel suffix to (srpm) package name when building kernel modules on builders
- autogenerate kernel BRs
- rel 10

* Sun Oct 27 2013 Jan Rękorajski <baggins@pld-linux.org> e607156
- fix kernel package release
- rel 9

* Sun Oct 27 2013 Jan Rękorajski <baggins@pld-linux.org> d2539c8
- switch to macro driven module build for multiple kernel versions
- rel 8

* Mon Oct 07 2013 Jan Rękorajski <baggins@pld-linux.org> 5a66963
- rebuild for kernel-3.10.15-1
- release 7 (by relup.sh)

* Wed Oct 02 2013 Jan Rękorajski <baggins@pld-linux.org> 8427afb
- rebuild for kernel-3.10.14-1
- release 6 (by relup.sh)

* Fri Sep 27 2013 Jan Rękorajski <baggins@pld-linux.org> a6b88e8
- rebuild for kernel-3.10.13-1
- release 5 (by relup.sh)

* Sun Sep 15 2013 Jan Rękorajski <baggins@pld-linux.org> e3356a4
- rebuild for kernel-3.10.12-1
- release 4 (by relup.sh)

* Tue Sep 10 2013 Jan Rękorajski <baggins@pld-linux.org> 49c8b14
- rebuild for kernel-3.10.11-1
- release 3 (by relup.sh)

* Fri Aug 30 2013 Jan Rękorajski <baggins@pld-linux.org> 87c325d
- rel 2, rebuild with kernel 3.10.10
- cosmetics

* Sun Aug 25 2013 Jakub Bogusz <qboosh@pld-linux.org> f47ff03
- added libdir patch (use LIB_SUFFIX)

* Sun Aug 25 2013 Jakub Bogusz <qboosh@pld-linux.org> bc65ae1
- new

